<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Redux_Framework_sample_config')) {

    class Redux_Framework_sample_config
    {

        public $args = array();
        public $sections = array();
        public $theme;
        public $ReduxFramework;

        public function __construct()
        {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if (true == Redux_Helpers::isTheme(__FILE__)) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }


        }

        public function initSettings()
        {

            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            //add_action( 'redux/loaded', array( $this, 'remove_demo' ) );

            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            add_filter('redux/options/' . $this->args['opt_name'] . '/compiler', array($this, 'compiler_action'), 10, 3);

            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );

            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );

            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**
         * This is a test function that will let you see when the compiler hook occurs.
         * It only runs if a field    set with compiler=>true is changed.
         * */
        function compiler_action($options, $css, $changed_values)
        {
            global $wp_filesystem;

            $filename = dirname(__FILE__) . '/style.css';
            //            var_dump($filename);die;

            if (empty($wp_filesystem)) {
                require_once(ABSPATH . '/wp-admin/includes/file.php');
                WP_Filesystem();
            }

            if ($wp_filesystem) {
                if ($wp_filesystem->put_contents(
                    $filename,
                    $css,
                    FS_CHMOD_FILE // predefined mode settings for WP files
                )
                ) {
                    echo("SUCCESS");
                } else {
                    echo("<h1> ERROR</h1>");
                    return false;
                }

            }
        }

        /**
         * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
         * Simply include this function in the child themes functions.php file.
         * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
         * so you must use get_template_directory_uri() if you want to use any of the built in icons
         * */
        function dynamic_section($sections)
        {
            //$sections = array();
            $sections[] = array(
                'title' => __('Section via hook', 'flotheme'),
                'desc' => __('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'flotheme'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }

        /**
         * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
         * */
        function change_arguments($args)
        {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**
         * Filter hook for filtering the default value of any given field. Very useful in development mode.
         * */
        function change_defaults($defaults)
        {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo()
        {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), NULL, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections()
        {

            /**
             * Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
             * */
            // Background Patterns Reader
            $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
            $sample_patterns_url = ReduxFramework::$_url . '../sample/patterns/';
            $sample_patterns = array();

            if (is_dir($sample_patterns_path)) :

                if ($sample_patterns_dir = opendir($sample_patterns_path)) :
                    $sample_patterns = array();

                    while (($sample_patterns_file = readdir($sample_patterns_dir)) !== false) {

                        if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                            $name = explode('.', $sample_patterns_file);
                            $name = str_replace('.' . end($name), '', $sample_patterns_file);
                            $sample_patterns[] = array(
                                'alt' => $name,
                                'img' => $sample_patterns_url . $sample_patterns_file
                            );
                        }
                    }
                endif;
            endif;

            ob_start();

            $ct = wp_get_theme();
            $this->theme = $ct;
            $item_name = $this->theme->get('Name');
            $tags = $this->theme->Tags;
            $screenshot = $this->theme->get_screenshot();
            $class = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'flotheme'), $this->theme->display('Name'));

            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
                <?php if ($screenshot) : ?>
                    <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize"
                           title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>"
                                 alt="<?php esc_attr_e('Current theme preview', 'flotheme'); ?>"/>
                        </a>
                    <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>"
                         alt="<?php esc_attr_e('Current theme preview', 'flotheme'); ?>"/>
                <?php endif; ?>

                <h4><?php echo $this->theme->display('Name'); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', 'flotheme'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', 'flotheme'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . __('Tags', 'flotheme') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo $this->theme->display('Description'); ?></p>
                    <?php
                    if ($this->theme->parent()) {
                        printf(' <p class="howto">' . __('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.', 'flotheme') . '</p>', __('http://codex.wordpress.org/Child_Themes', 'flotheme'), $this->theme->parent()->display('Name'));
                    }
                    ?>

                </div>
            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();

/*************************************NOTICE BY SLIVA*************************************/


/*WHEN YOU CREATE OPTION TYPE 'MEDIA' YOU NEED TO ADD OPTION ID TO THE ARRAY IN FLO_MAIN.PHP ($customizer_fields_array) */

	                        /* THIS IS NEEDED FOR CUSTOMIZER */

/*************************************END NOTICE BY SLIVA*********************************/


            // ACTUAL DECLARATION OF SECTIONS
            $dummy_data_folders = array('export' => __('Demo version 1', 'flotheme') , 'export2' => __('Demo version 2', 'flotheme'), /* 'export3' => __('Demo version 3', 'flotheme')*/);
            
            $predefined_stylesheet = array(
                '' => ReduxFramework::$_url . 'assets/img/icons/stylesheet_1.jpg',
                'style-white-bg.css' => ReduxFramework::$_url . 'assets/img/icons/stylesheet_2.jpg',

            );
            $this->sections[] = array(
                'title' => __('General Settings', 'flotheme'),
                'desc' => __('Check the theme documentation: </br> 
                    <a href="https://flothemes.zendesk.com/hc/en-us" style="top: 10px;position: relative;max-" target="_blank" >
                    <img style="position: relative;margin: 0 auto;display: block;margin-bottom: 30px;max-width:100%" src="' . get_template_directory_uri() . '/images/documentation_img.jpg" />
                    </a>', 'flotheme'),
                'icon' => 'general',

                'class' => 'general',
                'fields' => array(
                    array(
                        'id' => 'opt-import_one_click',
                        'type' => 'select',
                        'title' => 'Import Demo Content',
                        'subtitle' => sprintf(__('Before importing the content, please install and activate %sWidget Importer Exporter%s plugin if you want to import all the demo widgets. Also you may need to use %s Jetpack%s plugin with its %s Widget Visibility%s extension. ','flotheme'),'<a href="https://wordpress.org/plugins/widget-importer-exporter/" target="_blank">', '</a>','<a href="https://wordpress.org/plugins/jetpack/" target="_blank">','</a>','<a href="http://jetpack.me/support/widget-visibility/" target="_blank">','</a>'  ),
                        'options' => $dummy_data_folders,
                        'default' => 'export3',
                        'customizer' => false,
                        'desc' => '<input type="button" class="import-demo-content generic-record-button  button-primary  " value="' . __('Import dummy data','flotheme') . '" onclick="importDummyData();"> <div class="spinner-container"><span class="spinner import-demo-spinner" ></span></div><div class="import-response">' . __('Please be patient, the process may take some time.', 'flotheme') . '</div>'
                    ),
                    array(
                        'id' => 'flo-style_sheet',
                        'type' => 'image_select',
                        'customizer' => true,
                        'title' => __('Select the predefined stylesheet', 'flotheme'),
                        'options' => $predefined_stylesheet,
                        'class' => 'img-stylesheet',
                        'default' => ''
                    ),
                    array(
                        'id' => 'flo-show_admin_bar',
                        'type' => 'button_set',
                        'title' => __('Show WordPress admin bar', 'flotheme'),
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'customizer' => false,
                        'default' => true,
                    ),
                    array(
                        'id' => 'flo-tracking_code',
                        'type' => 'textarea',
                        'title' => __('Tracking code', 'flotheme'),
                        'default' => '',
                        'customizer' => true,
                        'hint' => array(

                            //'title'   => 'Hint Title',
                            'content' => __('Paste your Google Analytics or other tracking code here.
                                                It will be added into the footer of this theme', 'flotheme')
                        ),
                    ),
                    
	                array(
		                'id' => 'flo-content_width',
		                'type' => 'text',
		                'title' => __('Content width', 'flotheme'),
		                'default' => '1200',
		                'validation' => 'numeric',
		                'customizer' => true,
	                ),

                    array(
                        'id' => 'flo-favicon',
                        'type' => 'media',
                        'title' => __('Custom Favicon', 'flotheme'),
                        'desc' => __("Please select 'ico' type media file. Make sure you allow uploading 'ico' type in General Settings -> Upload file types. If you don't have a favicon, you can generate one using <a href='http://www.convertico.com/'>this service</a>", 'flotheme'),
                        'subtitle' => __('Upload any media using the WordPress native uploader', 'flotheme'),
                    ),

                    array(
                        'id' => 'flo-page_comments',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Enable comments for pages', 'flotheme'),
                        'default' => '0'
                    ),
                    array(
                        'id' => 'flo-social_for_pages',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Enable social sharing for pages', 'flotheme'),
                        'default' => '1'
                    ),
                    array(
                        'id' => 'flo-contact_email_address',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __("Contact Page: Email 'From' Field", 'flotheme'),
                        'subtitle' => __("Use the user's email address in the 'From' field", 'flotheme'),
                        'hint' => array(

                            //'title'   => 'Hint Title',
                            'content' => __('We recommended to enable this option. But on some hosting providers, if this option is enabled, 
                                then contact form emails may not be sent from some email addreses, in this case disable this option.', 'flotheme')
                        ),

                        'default' => '1'
                    ),
	                array(
		                'id' => 'flo-enable_clickable_grid_views',
		                'type' => 'button_set',
		                'options' => array(
				                '0' => 'Off',
				                '1' => 'On'
		                ),
		                'title' => __('Enable clickable Grid Views?', 'flotheme'),
                        'hint' => array(

                            //'title'   => 'Hint Title',
                            'content' => __('If this option is enabled, then for the majority of the grid views, the entire grid bloks will be clickable. While if this option is disabled, then only the post title of the thumbnail is clickable.', 'flotheme')
                        ),
                        'default' => '0'
	                ),
                    array(
                        'id' => 'flo_gallery_link',
                        'type' => 'text',
                        'title' => __('Gallery link URL(Gallery slug)', 'flotheme'),
                        'default' => 'gallery',
                        'customizer' => false,
                        'hint' => array(

                            //'title'   => 'Hint Title',
                            'content' => __('Set a custom permalink for your galleries. For example: portfolio. Example: http://yoursitename.com/portfolio', 'flotheme')
                        )
                    ),
                    array(
                        'id' => 'flo_gallery_categ_link',
                        'type' => 'text',
                        'title' => __('Gallery categories link URL(Gallery category slug)', 'flotheme'),
                        'default' => 'gallery-category',
                        'customizer' => false,
                        'hint' => array(

                            'content' => __('Set a custom permalink for your galleries categories. For example: portfolio. Example: http://yoursitename.com/portfolio', 'flotheme')
                        )
                    ),
                    array(
                        'id' => 'flo_gallery_tags_link',
                        'type' => 'text',
                        'title' => __('Gallery tags link URL(Gallery tag slug)', 'flotheme'),
                        'default' => 'gallery-tag',
                        'customizer' => true,
                        'hint' => array(

                            'content' => __('Set a custom permalink for your galleries tags. For example: portfolio. Example: http://yoursitename.com/portfolio', 'flotheme')
                        )
                    ),

                ),
            );
            $this->sections[] = array(
                'icon' => 'layout',
                'title' => __('Sidebar Layouts', 'flotheme'),
                'desc' => __('SIDEBARS LAYOUT PAGE SETTINGS', 'flotheme'),
                'class' => 'layout',
                'fields' => array(
                    array(
                        'id' => 'flo-sidebar_width',
                        'type' => 'select',
                        'title' => __('Sidebar width', 'flotheme'),
                        'options' => array('2' => '1/6', '3' => '1/4', '4' => '1/3', '5' => '5/12'),
                        'default' => '3',
                    ),
                    array(
                        'id' => 'flo-pages',
                        'type' => 'select',
                        'title' => __('Single pages layout', 'flotheme'),
                        'options' => array('left_sidebar' => 'Left Sidebar', 'right_sidebar' => 'Right Sidebar', 'full_width' => 'Full Width'),
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-pages-sidebar',
                        'type' => 'select',
                        'required' => array('flo-pages', '=', array('left_sidebar', 'right_sidebar')),
                        'title' => __('Sidebar', 'flotheme'),
                        'data' => 'sidebars',
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-single_posts',
                        'type' => 'select',
                        'title' => __('Single posts layout', 'flotheme'),
                        'options' => array('left_sidebar' => 'Left Sidebar', 'right_sidebar' => 'Right Sidebar', 'full_width' => 'Full Width'),
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-single_posts-sidebar',
                        'type' => 'select',
                        'required' => array('flo-single_posts', '=', array('left_sidebar', 'right_sidebar')),
                        'title' => __('Sidebar', 'flotheme'),
                        'data' => 'sidebars',
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-blog_posts',
                        'type' => 'select',
                        'title' => __('Blog page layout', 'flotheme'),
                        'options' => array('left_sidebar' => 'Left Sidebar', 'right_sidebar' => 'Right Sidebar', 'full_width' => 'Full Width'),
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-blog_posts-sidebar',
                        'type' => 'select',
                        'required' => array('flo-blog_posts', '=', array('left_sidebar', 'right_sidebar')),
                        'title' => __('Sidebar', 'flotheme'),
                        'data' => 'sidebars',
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-search',
                        'type' => 'select',
                        'title' => __('Search page layout', 'flotheme'),
                        'options' => array('left_sidebar' => 'Left Sidebar', 'right_sidebar' => 'Right Sidebar', 'full_width' => 'Full Width'),
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-search-sidebar',
                        'type' => 'select',
                        'required' => array('flo-search', '=', array('left_sidebar', 'right_sidebar')),
                        'title' => __('Sidebar', 'flotheme'),
                        'data' => 'sidebars',
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-archive',
                        'type' => 'select',
                        'title' => __('Archive page layout', 'flotheme'),
                        'options' => array('left_sidebar' => 'Left Sidebar', 'right_sidebar' => 'Right Sidebar', 'full_width' => 'Full Width'),
                        'default' => 'full_width',
                    ),
                    array(
                        'id' => 'flo-archive-sidebar',
                        'type' => 'select',
                        'required' => array('flo-archive', '=', array('left_sidebar', 'right_sidebar')),
                        'title' => __('Sidebar', 'flotheme'),
                        'data' => 'sidebars',
                        'default' => 'full_width',
                    ),
                ),
            );
            $current_path = ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/';
            $default_patterns = array(
                'arrow-glyph9'=> ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/icon-thin-right.jpg',
                'arrow-arrow99' => ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/icon-arrow-left.jpg',
                'arrow-bold' => ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/icon-bold-right.jpg',
                'arrow-smallbold' => ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/icon-smallbold-right.jpg',
                'arrow-square99' => ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/icon-square-right.jpg',
                'arrow-glyph27' => ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/icon-thin-right1.jpg',
                'arrow-border-glyph9' => ReduxFramework::$_url . 'assets/img/pattern/slider_arrows/arrows-circle.jpg',
            );
            $gallery_type = array(
                'two_columns' => ReduxFramework::$_url . 'assets/img/icons/gallery1.png',
                'horizontal_long' => ReduxFramework::$_url . 'assets/img/icons/gallery3.png',
                'fixed_with_thumbs' =>ReduxFramework::$_url . 'assets/img/icons/gallery2.png',
                'one_line' => ReduxFramework::$_url . 'assets/img/icons/single2.png',
            );
            $gallery_pagination_type = array(
                'thumb' => ReduxFramework::$_url . 'assets/img/icons/gallery_pagination1.png',
                'next_prev' => ReduxFramework::$_url . 'assets/img/icons/gallery_pagination2.png',
            );

            $this->sections[] = array(
                'icon' => 'sliders',
                'title' => __('Slideshow', 'flotheme'),
                'class' => 'sliders',
                'fields' => array(
                    array(
                        'id' => 'flo-slideshow_mob_fullscreen',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Enable full screen slideshow on mobile devices', 'flotheme'),
                        'default' => 1,
                    ),
                    array(
                        'id' => 'flo-main_slideshow_autoplay',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Enable autoplay for the main slideshow', 'flotheme'),
                        'default' => 0,
                    ),
                    array(
                        'id' => 'flo-autoplay_speed',
                        'type' => 'text',
                        'title' => __('Slideshow autoplay speed.', 'flotheme'),
                        'required' => array('flo-main_slideshow_autoplay', '=', '1'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'desc' => __('This is the description field, again good for additional info.', 'flotheme'),
                        'validate' => 'numeric',
                        'default' => '3000',
                    ),
                    array(
                        'id' => 'flo-slideshow_title',
                        'type' => 'typography',
                        'title' => __('Slideshow Title - Typography', 'flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => false,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'slideshow_title.jpg',
                        'output' => array('.hero-slider .slide-title'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

                            'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '55px',
                            'font-size-mobile' => '55px',
                            'font-size-tablet' => '55px',
                        ),
                    ),
                    array(
                        'id' => 'flo-slideshow_description',
                        'type' => 'typography',
                        'title' => __('Slideshow Description - Typography', 'flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => false,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'slideshow_description.jpg',
                        'output' => array('.hero-slider .slide-description'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

                                'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '18px',
                            'font-size-mobile' => '18px',
                            'font-size-tablet' => '18px',
                            //'line-height' => '40px'
                        ),
                    ),
//							array(
//									'id'      => 'flo-bullets_position',
//									'type'    => 'select',
//									'title'   => __('BULLETS POSITION', 'flotheme'),
//									'options' => array('horizontal' => 'Horizontal', 'vertical' => 'Vertical'),
//									'default' => 'horizontal',
//							),
//							array(
//									'id'       => 'flo-arrows_type',
//									'type'     => 'image_select',
//									'compiler' => true,
//									'title'    => __('SELECT MAIN SLIDESHOW ARROWS TYPE', 'flotheme'),
//									'subtitle' => __('The selected arrow type will be used for both main slideshow and single gallery slider.', 'flotheme'),
//									'options'  => $default_patterns,
//									'default'  => 'arrow-border-glyph9'
//							),
                    


                )
            );

            $this->sections[] = array(
                            'icon' => 'gallery',
                            'title' => __('Gallery', 'flotheme'),
                            'class' => 'gallery',
                            'fields' => array(
                                array(
                                    'id' => 'flo-gallery_type',
                                    'type' => 'image_select',
                                    'compiler' => true,
                                    'title' => __("Select default gallery's Sliders type", 'flotheme'),
                                    'subtitle' => __('The selected slider type will be as default value for the new created galleries. But you still can change the slider type for each gallery individually', 'flotheme'),
                                    'options' => $gallery_type,
                                    'default' => 'horizontal_long'
                                ),
                                array(
                                    'id' => 'flo-slides_desktop-height',
                                    'type' => 'text',
                                    'title' => __('Single gallery page - Slides desktop height', 'flotheme'),
                                    //'subtitle' => __('Featured image height for single video page. 600px by default.', 'flotheme'),
                                    'validate' => 'numeric',
                                    'mode' => 'max-height',
                                    'output' => array('.gallery-images .slick-slider img'),
                                    'default' => '600',
                                ),
                                array(
                                    'id' => 'flo-padding_between_images',
                                    'type' => 'text',
                                    'title' => __('Padding between images (in px)', 'flotheme'),
                                    'required' => array('flo-gallery_type', '=', 'horizontal_long'),
                                    'mode' => 'padding-right',
                                    'output' => array('.gallery .slick-initialized .slick-slide'),
                                    'help_img' => 'gallery-visible-nearby.jpg',
                                    'validate' => 'numeric',
                                    'default' => '0',
                                ),
                                // array(
                                //     'id' => 'flo-slides_mobile_height_full',
                                //     'type' => 'text',
                                //     'title' => __(' SINGLE GALLERY PAGE - SLIDES MOBILE HEIGHT (Full width)', 'flotheme'),
                                //     'subtitle' => __('Featured image height for single video page. 850px by default.', 'flotheme'),
                                //     'required' => array('flo-gallery_type', '=', 'full_width'),
                                //     'validate' => 'numeric',
                                //     'default' => '350',
                                // ),
                                // array(
                                //     'id' => 'flo-entry_meta_for_galleries',
                                //     'type' => 'button_set',
                                //     'options' => array(
                                //         '0' => 'Off',
                                //         '1' => 'On'
                                //     ),
                                //     'title' => __('SHOW ENTRY META ON SINGLE GALLERY PAGE', 'flotheme'),
                                //     'default' => '1'
                                // ),

                                // array(
                                //     'id' => 'flo-gallery_single_comments',
                                //     'type' => 'button_set',
                                //     'options' => array(
                                //         '0' => 'Off',
                                //         '1' => 'On'
                                //     ),
                                //     'title' => __('ENABLE COMMENTS FOR GALLERY SINGLE PAGE', 'flotheme'),
                                //     'default' => '1'
                                // ),
                                array(
                                    'id' => 'flo-social_for_galleries',
                                    'type' => 'button_set',
                                    'options' => array(
                                        '0' => 'Off',
                                        '1' => 'On'
                                    ),
                                    'title' => __('Enable social sharing for Galleries', 'flotheme'),
                                    'default' => '1'
                                ),
                                array(
                                    'id' => 'flo-back_to_galleries_link',
                                    'type' => 'select',
                                    'data' => 'pages',
                                    'title' => __("Back to Galeries link", 'flotheme'),

                                ),
                                array(
                                    'id' => 'flo-back_to_galleries_label',
                                    'type' => 'text',
                                    'title' => __("Back to galleries label", 'flotheme'),

                                ),
                                array(
                                    'id' => 'flo-gallery_pagination_type',
                                    'type' => 'image_select',
                                    'title' => __("Select Gallery'S pagination type", 'flotheme'),
                                    'options' => $gallery_pagination_type,
                                    'default' => 'next_prev'
                                ),
                            )
            );

            $single_view_type = array(
                'default' => ReduxFramework::$_url . 'assets/img/icons/single2.png',
                'full_screen' => ReduxFramework::$_url . 'assets/img/icons/single1.png',
            );

            $this->sections[] = array(
                'icon' => 'blog-post',
                'class' => 'blog-post',
                'title' => __('Blog Post', 'flotheme'),
                'fields' => array(
                    array(
                        'id' => 'flo-single_view_type',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => __('Single View Type', 'flotheme'),
                        'subtitle' => __('Choose single view type.', 'flotheme'),
                        'options' => $single_view_type,
                        'default' => 'full_screen'
                    ),
                    array(
                        'id' => 'flo-similar',
                        'type' => 'button_set',
                        'title' => __('Show similar posts on single blog post page?', 'flotheme'),
                        'subtitle' => __('With the "section" field you can create indent option sections.', 'flotheme'),
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'default' => '1'
                    ),
                    array(
                        'id' => 'flo-similar_criteria',
                        'type' => 'select',
                        'title' => __('Similar posts criteria', 'flotheme'),
                        'options' => array('post_tag' => 'Same Tags', 'category' => 'Same Category'),
                        'required' => array('flo-similar', "=", 1),
                        'default' => 'category'
                    ),
                    array(
                        'id' => 'flo-image_distance',
                        'type' => 'text',
                        'title' => __('Distance below post images', 'flotheme'),
                        'subtitle' => __('Set the vertical distance between images inserted in the post content', 'flotheme'),
                        'validate' => 'numeric',
                        'default' => '5',
                        'mode' => 'margin-bottom',
                        'output' => array('.entry-content a img, .entry-content img, .entry-content img.alignleft, .entry-content img.alignright, .entry-content img.aligncenter,
                            .page.open-post .entry-content a img, .page.open-post .entry-content img, .page.open-post .entry-content img.alignleft, .page.open-post .entry-content img.alignright, .page.open-post .entry-content img.aligncenter'),
                    ),
                    array(
                        'id' => 'flo-social_sharing',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Enable social sharing for the posts', 'flotheme'),
                        'default' => '1'
                    ),
                    array(
                        'id' => 'flo-set_featured',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Auto set featured images', 'flotheme'),
                        'subtitle' => __('Auto set featured images for blog posts and gallery posts if it is missing.', 'flotheme'),
                        'default' => '1'
                    ),
                    array(
                        'id' => 'flo-featured_on_single',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Show featured image on single blog post page?', 'flotheme'),
                        'default' => '1'
                    ),
                    // array(
                    //     'id' => 'flo-entry_meta',
                    //     'type' => 'button_set',
                    //     'options' => array(
                    //         '0' => 'Off',
                    //         '1' => 'On'
                    //     ),
                    //     'title' => __('SHOW ENTRY META', 'flotheme'),
                    //     'subtitle' => __('In blog / archive / search / tag / category page', 'flotheme'),
                    //     'default' => '1'
                    // ),
                    array(
                        'id' => 'flo-blog_post_tags',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __('Show blog post tags?', 'flotheme'),
                        'default' => '1'
                    ),
                    array(
                        'id' => 'flo-comments',
                        'type' => 'sorter',
                        'title' => 'Comments options',
                        'compiler' => 'true',
                        'options' => array(
                            'Enabled' => array(
                                'wp' => 'WP comments',
                            ),
                            'Disabled' => array(
                                'facebook' => 'Facebook Comments'
                            ),
                        ),
                        'limits' => array(
                            'disabled' => 2,
                            'enabled' => 2,
                        ),


                    ),
                    array(
                        'id' => 'flo-fb_id',
                        'type' => 'text',
                        'title' => __('Facebook application ID', 'flotheme'),
                        'subtitle' => __('This is necessary if you want to moderate the FB comments', 'flotheme'),
                    ),

                )
            );

            $pag_type = array(
                'small' => ReduxFramework::$_url . 'assets/img/icons/pagination1.png',
                'next_prev' => ReduxFramework::$_url . 'assets/img/icons/pagination3.png',
                'dots' => ReduxFramework::$_url . 'assets/img/icons/pagination2.png'
            );
            $page_view_type = array(
                '1' => ReduxFramework::$_url . 'assets/img/icons/page2.png',
                '2' => ReduxFramework::$_url . 'assets/img/icons/page1.png',
            );
            
//            $this->sections[] = array(
//                'icon' => 'colors',
//                'class' => 'colors',
//                'title' => __('Colors', 'flotheme'),
//                'fields' => array(
//                    array(
//                        'id' => 'flo-menu_links_color',
//                        'type' => 'color',
//                        'output' => array('.header_main-nav_link a'),
//                        'title' => __('Menu Link Color', 'flotheme'),
//                        'subtitle' => __('Pick a Menu Links color.', 'flotheme'),
//                        'default' => '#504c49',
//                        'mode' => 'color',
//                        'validate' => 'color',
//                    ),
//                    array(
//                        'id' => 'flo-sub_menu_links_color',
//                        'type' => 'color',
//                        'output' => array('.header_main-nav_link .children .header_main-nav_sub-menu_link a'),
//                        'title' => __('Sub Menu Link Color', 'flotheme'),
//                        'subtitle' => __('Pick a Sub Menu Links color.', 'flotheme'),
//                        'default' => '#504c49',
//                        'mode' => 'color',
//                        'validate' => 'color',
//                    ),
//                    array(
//                        'id' => 'flo-sub_menu_background color_color',
//                        'type' => 'color',
//                        'output' => array('.header_main-nav_link .children'),
//                        'title' => __('Menu Link Color', 'flotheme'),
//                        'subtitle' => __('Pick a Menu Links color.', 'flotheme'),
//                        'default' => '#ffffff',
//                        'mode' => 'background-color',
//                        'validate' => 'color',
//                    ),
//
//                    array(
//                        'id' => 'opt-color-background',
//                        'type' => 'color',
//                        'output' => array('body'),
//                        'title' => __('Body Background Color', 'flotheme'),
//                        'subtitle' => __('Pick a background color for the theme (default: #fff).', 'flotheme'),
//                        'default' => '#f2eeeb',
//                        'mode' => 'background-color',
//                        'validate' => 'color',
//                    ),
//                    array(
//                        'id' => 'opt-content_background_color',
//                        'type' => 'color',
//                        'output' => array('.single-page.content-full-width .page-content .inner'),
//                        'title' => __('Content Background Color', 'flotheme'),
//                        'subtitle' => __('Pick a content background color for the theme (default: #fff).', 'flotheme'),
//                        'default' => '#FFFFFF',
//                        'mode' => 'background-color',
//                        'validate' => 'color',
//                    ),
//                    array(
//                        'id' => 'opt-text_color',
//                        'type' => 'color',
//                        'output' => array('p'),
//                        'title' => __('Content Text Color', 'flotheme'),
//                        'subtitle' => __('Pick a content text color for the theme .', 'flotheme'),
//                        'default' => '#504c49',
//                        'mode' => 'color',
//                        'validate' => 'color',
//                    ),
//                    array(
//                        'id' => 'opt-titles_color',
//                        'type' => 'color',
//                        'output' => array('h1,h2,h3,h4,h5,h6'),
//                        'title' => __('Content Titles Color', 'flotheme'),
//                        'subtitle' => __('Pick a content titles color for the theme .', 'flotheme'),
//                        'default' => '#504c49',
//                        'mode' => 'color',
//                        'validate' => 'color',
//                    ),
//                    array(
//                        'id' => 'opt-links_color',
//                        'type' => 'color',
//                        'output' => array('a'),
//                        'title' => __('Content Links Color', 'flotheme'),
//                        'subtitle' => __('Pick a content links color for the theme .', 'flotheme'),
//                        'default' => '#504c49',
//                        'mode' => 'color',
//                        'validate' => 'color',
//                    ),
////                    array(
////                        'id' => 'opt-spacingss',
////                        'type' => 'spacing',
////                        'customizer' => true,
////                        //                        'output' => array('.site-header'),
////                        // An array of CSS selectors to apply this font style to
////                        'mode' => 'margin',
////                        // absolute, padding, margin, defaults to padding
////                        'all' => true,
////                        // Have one field that applies to all
////                        'top' => false, // Disable the top
////                        'right' => false, // Disable the right
////                        'bottom' => false, // Disable the bottom
////                        'left' => false, // Disable the left
////                        'units' => 'em', // You can specify a unit value. Possible: px, em, %
////                        'units_extended' => 'true', // Allow users to select any type of unit
////                        'display_units' => 'false', // Set to false to hide the units if the units are specified
////                        'title' => __('Padding/Margin Option', 'flotheme'),
////                        'subtitle' => __('Allow your users to choose the spacing or margin they want.', 'flotheme'),
////                        'desc' => __('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'flotheme'),
////                        'default' => array(
////                            'margin-top' => '1px',
////                            'margin-right' => '2px',
////                            'margin-bottom' => '3px',
////                            'margin-left' => '4px'
////                        )
////                    ),
//                    array(
//                        'id' => 'opt-background',
//                        'type' => 'background',
//                        //                        'output' => array('body'),
//                        'title' => __('Body Background', 'flotheme'),
//                        'subtitle' => __('Body background with image, color, etc.', 'flotheme'),
//                        'default' => '#FFFFFF',
//                    ),
//                    array(
//                        'id' => 'opt-color-footer',
//                        'type' => 'color',
//                        'title' => __('Footer Background Color', 'flotheme'),
//                        'subtitle' => __('Pick a background color for the footer (default: #dd9933).', 'flotheme'),
//                        'default' => '#dd9933',
//                        'validate' => 'color',
//                    ),
//                    array(
//                        'id' => 'opt-color-rgba',
//                        'type' => 'color_rgba',
//                        'title' => __('Color RGBA', 'flotheme'),
//                        'subtitle' => __('Gives you the RGBA color.', 'flotheme'),
//                        'default' => array(
//                            'color' => '#cccccc',
//                            'alpha' => '.8'
//                        ),
//                        //                        'output' => array('body'),
//                        'mode' => 'background',
//                        'validate' => 'colorrgba',
//                    ),
//                    array(
//                        'id' => 'opt-color-header',
//                        'type' => 'color_gradient',
//                        'title' => __('Header Gradient Color Option', 'flotheme'),
//                        'subtitle' => __('Only color validation can be done on this field type', 'flotheme'),
//                        'desc' => __('This is the description field, again good for additional info.', 'flotheme'),
//                        'default' => array(
//                            'from' => '#1e73be',
//                            'to' => '#00897e'
//                        )
//                    ),
//                )
//            );

            //Typography section
            $this->sections[] = array(
                'icon' => 'typography',
                'class' => 'typography',
                'title' => __('Typography', 'flotheme'),
                //'desc' => __('<p class="description">This is the Description. Again HTML is allowed</p>', 'flotheme'),
                'fields' => array(
                    array(
                        'id' => 'opt-typography-general',
                        'type' => 'typography',
                        'title' => __('General font', 'flotheme'),
                        'subtitle' => __('default font: "Adobe Caslon Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('body'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

		                    'font-weight'  => '400',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '0.9px',
                            'font-size' => '18px',
                            'font-size-mobile' => '16px',
                            'font-size-tablet' => '17px',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-post-title',
                        'type' => 'typography',
                        'title' => __('Single Blog/Page post title', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('.single .entry-title, .page .entry-title, .page-content .page-header .entry-title, .single-page.content-full-width .page-content .page-title,
                                            .page.open-post .featured-image .post-title'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-gallery-title',
                        'type' => 'typography',
                        'title' => __('Single Gallery post title', 'flotheme'),
                        'subtitle' => __('default font: "Brandon-Light"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('.gallery.one-line .gallery-name, 
                            .gallery .gallery-info.under-slider .gallery-name, 
                            .single.single-gallery .entry-title'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-h1',
                        'type' => 'typography',
                        'title' => __('H1 Font', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('h1'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-h2',
                        'type' => 'typography',
                        'title' => __('H2 Font', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('h2'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-h3',
                        'type' => 'typography',
                        'title' => __('H3 Font', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('h3'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-h4',
                        'type' => 'typography',
                        'title' => __('H4 Font', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('h4'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-h5',
                        'type' => 'typography',
                        'title' => __('H5 Font', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('h5'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'opt-typography-h6',
                        'type' => 'typography',
                        'title' => __('H6 Font', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'output' => array('h6'),
                        'units' => 'px',
                        //'subtitle' => __('Typography option with each property can be called individually.', 'flotheme'),
                        'placeholder' => array(

                            'font-weight'  => '',
                            'color'       => '',
                            'font-family' => '',
                            'google' => true,
                            'letter-spacing' => '',
                            'font-size' => '',
                            'font-size-mobile' => '',
                            'font-size-tablet' => '',
                        ),
                    ),
                    array(
                        'id' => 'flo-labels',
                        'type' => 'typography',
                        'title' => __('Labels', 'flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-weight to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'output' => array('.item .read-more'),
                        'subtitle' => __('Read more / social labels / placeholders / small page view label / menu description ', 'flotheme'),
                        'help_img' => 'labels.jpg',
                        'placeholder' => array(

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '17px',
                            'font-size-mobile' => '15px',
                            'font-size-tablet' => '16px',
                        ),
                    ),
                    
                    
                    array(
                        'id' => 'flo-grid_description',
                        'type' => 'typography',
                        'title' => __('Widget Posts Slideshow excerpt', 'flotheme'),
                        'subtitle' => __('default font: "Adobe Caslon Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'grid_widget_slideshow_description.jpg',
                        'output' => array('.horizontal-slider .slide .content'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '14px',
                            'font-size-mobile' => '14px',
                            'font-size-tablet' => '14px',
                        ),
                    ),
                    array(
                        'id' => 'flo-slideshow_widget_title',
                        'type' => 'typography',
                        'title' => __('Slideshow Widget Title', 'flotheme'),
                        'subtitle' => __('default font: "Didot Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'grid_widget_slideshow_title.jpg',
                        'output' => array('.horizontal-slider .slide .title'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '25px',
                            'font-size-mobile' => '25px',
                            'font-size-tablet' => '25px',
                            'letter-spacing' => '2.5px'
                        ),
                    ),
                    array(
                        'id' => 'flo-grid_title',
                        'type' => 'typography',
                        'title' => __('Grid/Grid_50-50 Title', 'flotheme'),
                        'subtitle' => __('default font: "Adobe Caslon Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'grid_view_title.jpg',
                        'output' => array('.columns-image-vertical .item .title, .description.full-description h3.title'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '14px',
                            'font-size-mobile' => '14px',
                            'font-size-tablet' => '14px',
                            'line-spacing' => '2.1px',
                            'line-height'  => '16px'

                        ),
                    ),
                    array(
                        'id' => 'flo-grid_meta',
                        'type' => 'typography',
                        'title' => __('Grid Meta', 'flotheme'),
                        'subtitle' => __('default font: "Gotham-Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'grid_view_meta.jpg',
                        'output' => array('.columns-image-vertical .item .date'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

                                'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '11px',
                            'font-size-mobile' => '11px',
                            'font-size-tablet' => '11px',
                            'letter-spacing' => '1.1px'
                        ),
                    ),
                    array(
                        'id' => 'flo-list_50x50_title',
                        'type' => 'typography',
                        'title' => __('List 50x50 title', 'flotheme'),
                        'subtitle' => __('default font: "Didot Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'list_50x50_title.jpg',
                        'output' => array('.one-column-vertical .item .title'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '33px',
                            'font-size-mobile' => '33px',
                            'font-size-tablet' => '33px',

                            'font-weight'  => '400',
                        ),
                    ),
                    array(
                        'id' => 'flo-list_50x50_meta',
                        'type' => 'typography',
                        'title' => __('List 50x50 meta', 'flotheme'),
                        'subtitle' => __('default font: "Pinyon-Script"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'list_50x50_meta.jpg',
                        'output' => array('.one-column-vertical .item .before-title'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '38px',
                            'font-size-mobile' => '38px',
                            'font-size-tablet' => '38px',

                            'font-weight'  => '400',
                        ),
                    ),
                    array(
                        'id' => 'flo-thumb_view_title',
                        'type' => 'typography',
                        'title' => __('Thumb View Title', 'flotheme'),
                        'subtitle' => __('default font: "Didot Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'thumb_view_title.jpg',
                        'output' => array('.columns-full-width .item .title'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '39px',
                            'font-size-mobile' => '39px',
                            'font-size-tablet' => '39px',
                            'line-height' => '50px'
                        ),
                    ),
                    array(
                        'id' => 'flo-thumb_view_meta',
                        'type' => 'typography',
                        'title' => __('Thumb View Meta', 'flotheme'),
                        'subtitle' => __('default font: "Gotham-Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'thumb_view_meta.jpg',
                        'output' => array('.columns-full-width .item .before-title'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '15px',
                            'font-size-mobile' => '15px',
                            'font-size-tablet' => '15px',
                            'letter-spacing' => '1.5px'
                        ),
                    ),
                    
                    array(
                        'id' => 'flo-big_mosaic_title',
                        'type' => 'typography',
                        'title' => __('Mosaic grid title for big item / Featured  grid post title', 'flotheme'),
                        'subtitle' => __('default font: "Didot Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'mosaic_big_title.jpg',
                        'output' => array('.mosaic-grid .big-one .title', '.six-square-grid .big-one .title'),
                        'placeholder' => array(

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '39px',
                            'font-size-mobile' => '39px',
                            'font-size-tablet' => '39px',
                            'lletter-spacing' => '0px',
                            'line-height' => '50px'
                        ),
                    ),
                    array(
                        'id' => 'flo-small_mosaic_title',
                        'type' => 'typography',
                        'title' => __('Mosaic grid title for small items.', 'flotheme'),
                        'subtitle' => __('default font: "Didot-Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'mosaic_small_title.jpg',
                        'output' => array('.mosaic-grid .with-image .title', '.mosaic-grid .without-image .title '),
                        'placeholder' => array(

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '25px',
                            'font-size-mobile' => '25px',
                            'font-size-tablet' => '25px',
                            'line-height' => '28px'
                        ),
                    ),
                    array(
                        'id' => 'flo-big_mosaic_meta',
                        'type' => 'typography',
                        'title' => __('Mosaic grid meta for big item / Featured grid post meta', 'flotheme'),
                        'subtitle' => __('default font: "Gotham-Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'mosaic_big_meta.jpg',
                        'output' => array('.mosaic-grid .big-one .before-title', '.six-square-grid .big-one .before-title'),
                        'placeholder' => array(

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '12px',
                            'font-size-mobile' => '12px',
                            'font-size-tablet' => '12px',
                            'letter-spacing' => '1.2px'
                        ),
                    ),
                    array(
                        'id' => 'flo-small_mosaic_meta',
                        'type' => 'typography',
                        'title' => __('Mosaic grid meta for small item .', 'flotheme'),
                        'subtitle' => __('default font: "Gotham-Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'mosaic_small_meta.jpg',
                        'output' => array('.mosaic-grid .with-image .before-title', '.mosaic-grid  .without-image .before-title'),
                        'placeholder' => array(

		                        'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '12px',
                            'font-size-mobile' => '12px',
                            'font-size-tablet' => '12px',
                            'letter-spacing' => '1.2px'
                        ),
                    ),
                    array(
                        'id' => 'flo-video_widget_title',
                        'type' => 'typography',
                        'title' => __('Video Widget title', 'flotheme'),
                        'subtitle' => __('default font: "Didot Regular"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'video_widget_title.jpg',
                        'output' => array('.video-element .title'),
                        'placeholder' => array(
                            'color'       => '#fff',

                            'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '39px',
                            'font-size-mobile' => '39px',
                            'font-size-tablet' => '39px',
                            'letter-spacing' => '5.85px'
                        ),
                    ),
                    array(
                        'id' => 'flo-popular_posts_widget_title',
                        'type' => 'typography',
                        'title' => __('Flo Block posts (Popular posts) widget title', 'flotheme'),
                        'subtitle' => __('default font: "Didot Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'popular_posts_widget_title.jpg',
                        'output' => array('grid-with-title .title-part .title'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '39px',
                            'font-size-mobile' => '39px',
                            'font-size-tablet' => '39px',

                            'font-weight'  => '400',
                        ),
                    ),
                    array(
                        'id' => 'flo-popular_posts_post_title',
                        'type' => 'typography',
                        'title' => __('Flo Block posts widget - post title', 'flotheme'),
                        'subtitle' => __('default font: "Gotham Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'popular_posts_post_title.jpg',
                        'output' => array('grid-with-title .grid-part .title .inner a'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '10px',
                            'font-size-mobile' => '10px',
                            'font-size-tablet' => '10px',
                            'letter-spacing' => '1px',

                            'font-weight'  => '400',
                        ),
                    ),
                    
                    array(
                        'id' => 'flo-read_more_button',
                        'type' => 'typography',
                        'title' => __('Read more button ', 'flotheme'),
                        'subtitle' => __('default font: "Gotham Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'read_more_button.jpg',
                        'output' => array('.inner a.btn'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '10px',
                            'font-size-mobile' => '10px',
                            'font-size-tablet' => '10px',
                            'latter-spacing' => '1px',

                            'font-weight'  => '400',
                        ),
                    ),
                    array(
                        'id' => 'flo-widgets_title',
                        'type' => 'typography',
                        'title' => __('Widgets title', 'flotheme'),
                        'subtitle' => __('default font: "Gotham Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'widgets_title.jpg',
                        'output' => array('footer.main-footer .footer-block .widget-title'),
                        'placeholder' => array(
                            'font-family' => '',
                            'letter-spacing' => '1.2px',
                            'font-size' => '12px',

                            'font-weight'  => '400',
                        ),
                    ),
                    array(
                        'id' => 'flo-post_page_sidebar_info_title',
                        'type' => 'typography',
                        'title' => __('Post/Page sidebar info Title', 'flotheme'),
                        'subtitle' => __('default font: "Adobe Caslon Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'posts_pages_sidebar_info.jpg',
                        'output' => array('.content-sidebar .widget-block .widget-title'),
                        'placeholder' => array(
                            'google' => true,
                            'font-size' => '13px',
                            'font-size-mobile' => '13px',
                            'font-size-tablet' => '13px',

                            'font-style'  => '700',
                        ),
                    ),
                    array(
                        'id' => 'flo-post_page_sidebar_info_content',
                        'type' => 'typography',
                        'title' => __('Post/Page sidebar info Content', 'flotheme'),
                        'subtitle' => __('default font: "Adobe Caslon Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'posts_pages_sidebar_info.jpg',
                        'output' => array('.content-sidebar .widget-block article.content'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '11px',
                            'font-size-mobile' => '11px',
                            'font-size-tablet' => '11px',
                            'line-height' => '25px',

                            'font-weight'  => '400',
                        ),
                    ),
                    array(
                        'id' => 'flo-single_title_feat_image',
                        'type' => 'typography',
                        'title' => __('Single title on top of featured image', 'flotheme'),
                        'subtitle' => __('default font: "Brandon-Light"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'single_title_on_top_of_featured_image.jpg',
                        'output' => array('six-square-grid .big-one .before-title'),
                        'placeholder' => array(
                            //'color'       => '#333',
                            //'font-style'  => '700',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '12px',
                            'font-size-mobile' => '12px',
                            'font-size-tablet' => '12px',
                            'letter-spacing' => '1.2px',

                            'font-weight'  => '400',
                            //'line-height' => '40px'
                        ),
                    ),
                    array(
                        'id' => 'flo-pagination_label',
                        'type' => 'typography',
                        'title' => __('Pagination Label', 'flotheme'),
                        'subtitle' => __('default font: "Adobe Caslon Italic"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'pagination_label.jpg',
                        'output' => array('.block.pagination.page-counter li.counter'),
                        'placeholder' => array(
                            'google' => true,
                            'font-size' => '16px',
                            'font-size-mobile' => '16px',
                            'font-size-tablet' => '16px',

                            'font-weight'  => '400',
                        ),
                    ),
                    array(
                        'id' => 'flo-contact_form_placeholders',
                        'type' => 'typography',
                        'title' => __('Contact form inputs', 'flotheme'),
                        'subtitle' => __('default font: "Gotham Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => false,
                        'line-height-mobile' => false,
                        'line-height-tablet' => false,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'contact_form_placeholders.jpg',
                        'output' => array('.contact-form-template input[type="text"]', '.contact-form-template input[type="password"]', '.contact-form-template input[type="email"]', '.contact-form-template textarea'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '12px',
                            'font-size-mobile' => '12px',
                            'font-size-tablet' => '12px',
                            'letter-spacing' => '1.2px',

                            'font-weight'  => '400',
                        ),
                    ),array(
                        'id' => 'flo-back_to_galleries',
                        'type' => 'typography',
                        'title' => __('Back to galleries / Next/Prev / hide thumbs', 'flotheme'),
                        'subtitle' => __('default font: "Gotham Medium"','flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'back_to_galleries_next_prev.jpg',
                        'output' => array('.gallery-info a.back', '.gallery-nav .next', '.gallery-nav .prev', '.gallery .sub-thumbs a.hide-thumbs'),
                        'placeholder' => array(
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '9px',
                            'font-size-mobile' => '9px',
                            'font-size-tablet' => '9px',
                            'letter-spacing' => '0.9px',

                            'font-weight'  => '400',

                        ),
                    ),
                )

            );

            $this->sections[] = array(
                'icon' => 'imagesizes',
                'class' => 'imagesizes',
                'title' => __('Image Sizes', 'flotheme'),
                //'desc' => __('<p class="description">This is the Description. Again HTML is allowed</p>', 'flotheme'),
                //                    'id' => 'imagesizes',
                'fields' => array(
                    array(
                        'id' => 'flo_grid_50_50-height',
                        'type' => 'text',
                        'title' => __('Grid 50/50 image height&width', 'flotheme'),
                        'class' => 'bottom-separator',
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'help_img' => 'grid_50_50_height_width.jpg',
                        'default' => '600',
                    ),
                    /*-----------------------------------*/
                    array(
                        'id' => 'flo_grid_mosaic-width',
                        'type' => 'text',
                        'title' => __('Grid mosaic image width&height', 'flotheme'),
                        'subtitle' => __('This must be numeric. This size is for the small thumbnail, the bigger thumbnail will be 2 times larger the size you set here', 'flotheme'),
                        'validate' => 'numeric',
                        'help_img' => 'mosaic_grid_height_width.jpg',
                        'class' => 'bottom-separator',
                        'default' => '300',
                    ),
                    /*-----------------------------------*/
                    array(
                        'id' => 'flo_grid_view-width',
                        'type' => 'text',
                        'title' => __('Grid view image width', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'help_img' => 'grid_view_width_height.jpg',
                        'default' => '600',
                    ),
                    array(
                        'id' => 'flo_grid_view-height',
                        'type' => 'text',
                        'title' => __('Grid view image height', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'class' => 'bottom-separator',
                        'help_img' => 'grid_view_width_height.jpg',
                        'default' => '600',
                    ),
                    /*-----------------------------------*/

                    array(
                        'id' => 'flo_list_view-width',
                        'type' => 'text',
                        'title' => __('List view image width', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'help_img' => 'grid_view_width_height.jpg',
                        'default' => '1200',
                    ),
                    array(
                        'id' => 'flo_list_view-height',
                        'type' => 'text',
                        'title' => __('List view image height', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'class' => 'bottom-separator',
                        'help_img' => 'grid_view_width_height.jpg',
                        'default' => '500',
                    ),
                    
                    /*-----------------------------------*/
                    array(
                        'id' => 'flo_featured_image-height',
                        'type' => 'text',
                        'title' => __('Grid view featured image height&width', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'help_img' => 'grid_feathured_width_height.jpg',
                        'validate' => 'numeric',
                        'class' => 'bottom-separator',
                        'default' => '400',
                    ),
                    /*-----------------------------------*/

                    // array(
                    //     'id' => 'flo_featured_image-width',
                    //     'type' => 'text',
                    //     'title' => __('Grid wiew featured image width', 'flotheme'),
                    //     'subtitle' => __('This must be numeric.', 'flotheme'),
                    //     'validate' => 'numeric',
                    //     'help_img' => 'grid_feathured_width_height.jpg',
                    //     'default' => '200',
                    // ),
                    array(
                        'id' => 'flo_list_50_50-width',
                        'type' => 'text',
                        'title' => __('List view 50/50 image width', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'help_img' => 'list_50_50_height_width.jpg',
                        'class' => 'bottom-separator',
                        'default' => '600',
                    ),
                    // array(
                    //     'id' => 'flo_list_50_50-height',
                    //     'type' => 'text',
                    //     'title' => __('List view 50/50 image height', 'flotheme'),
                    //     'subtitle' => __('This must be numeric.', 'flotheme'),
                    //     'help_img' => 'list_50_50_height_width.jpg',
                    //     'validate' => 'numeric',
                    //     'class' => 'bottom-separator',
                    //     'default' => '750',
                    // ),
                    
                    /*-----------------------------------*/
                    array(
                        'id' => 'flo_title_below-width',
                        'type' => 'text',
                        'title' => __('Grid view title below image width', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'help_img' => 'title_below_height_width.jpg',
                        'default' => '809',
                    ),
                    array(
                        'id' => 'flo_title_below-height',
                        'type' => 'text',
                        'title' => __('Grid view title below image height', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'help_img' => 'title_below_height_width.jpg',
                        'validate' => 'numeric',
                        'class' => 'bottom-separator',
                        'default' => '580',
                    ),
                    
                    /*-----------------------------------*/
                    array(
                        'id' => 'flo_title_over-width',
                        'type' => 'text',
                        'title' => __('Grid view title over image width', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'validate' => 'numeric',
                        'help_img' => 'title_over_height_width.jpg',
                        'default' => '600',
                    ),
                    array(
                        'id' => 'flo_title_over-height',
                        'type' => 'text',
                        'title' => __('Grid view title over image height', 'flotheme'),
                        'subtitle' => __('This must be numeric.', 'flotheme'),
                        'help_img' => 'title_over_height_width.jpg',
                        'validate' => 'numeric',
                        'default' => '460',
                    ),
                    
                )
            );

            
            $header_type = array(
                'header_logo_outside' => ReduxFramework::$_url . 'assets/img/icons/header1.png',
                'header_hamburger' => ReduxFramework::$_url . 'assets/img/icons/header2.png',
                'header_logo_inside' => ReduxFramework::$_url . 'assets/img/icons/header3.png',
            );
            $this->sections[] = array(
                'icon' => 'header-settings',
                'class' => 'header-settings',
                'title' => __('Header Settings', 'flotheme'),
                'fields' => array(
                    //
                    

                    array(
                        'id' => 'flo-header_type',
                        'type' => 'image_select',
                        'compiler' => true,
                        'customizer' => true,
                        'title' => __('Logo & Navigation', 'flotheme'),
                        'subtitle' => __('Choose your Logo and Navigation layout.', 'flotheme'),
                        'options' => $header_type,
                        'default' => 'header_logo_outside'
                    ),
                    array(
                        'id' => 'flo-logo_position',
                        'type' => 'select',
                        'title' => __('Logo position', 'flotheme'),
                        'options' => array(
                            '1' => 'Left',
                            '2' => 'Center',
                            '3' => 'Right'
                        ),
                        'required' => array('flo-header_type', '=', 'header_logo_inside'),
                        'default' => '2',
                    ),
		                array(
				                'id' => 'flo-enable_sticky_header',
				                'type' => 'button_set',
				                'options' => array(
						                '0' => 'Off',
						                '1' => 'On'
				                ),
				                'customizer' => true,
				                'title' => __("Enable Sticky Header?", 'flotheme'),
				                'default' => '0',
		                ),

                    array(
                        'id' => 'flo-enable_menu_description',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'customizer' => true,
                        'title' => __("Enable menu description?", 'flotheme'),
                        'default' => '0',
                        'help_img' => 'menu-description.jpg',
                    ),
                    array(
                       'id' => 'header-background_color',
                       'type' => 'color',
                       'output' => array('.main-header'),
                       'title' => __('Header Background Color', 'flotheme'),
                       //'subtitle' => __('Pick a content text color for the theme .', 'flotheme'),
                       'default' => '',
                       'mode' => 'background-color',
                       'validate' => 'color',
                    ),
                    array(
                        'id' => 'flo-logo_type',
                        'type' => 'select',
                        'title' => __('Logo Type', 'flotheme'),
                        'options' => array('text' => 'Text Logo', 'image' => 'Image Logo'),
                        'default' => 'text',
                    ),
                    array(
                        'id' => 'flo-logo_image_desktop',
                        'class' => 'child_class',
                        'type' => 'media',
                        'required' => array('flo-logo_type', '=', 'image'),
                        'title' => __('Upload the logo image', 'flotheme'),
                    ),
                    array(
                        'id' => 'flo-logo_image_mobile',
                        'class' => 'child_class',
                        'type' => 'media',
                        'required' => array('flo-logo_type', '=', 'image'),
                        'title' => __('Upload the mobile logo image', 'flotheme'),
                    ),
                    array(
                            'id' => 'flo-max_logo_width',
                            'type' => 'text',
                            'title' => __('Max Logo Width (in px)', 'flotheme'),
                            'default' => '',
                            'validate' => 'numeric',
                            'customizer' => true,
                    ),
                    array(
                            'id' => 'flo-max_logo_mobile_width',
                            'type' => 'text',
                            'title' => __('Max Logo mobile Width (in px)', 'flotheme'),
                            'default' => '',
                            'validate' => 'numeric',
                            'class' => '',
                            'customizer' => true,
                    ),

                    array(
                        'id' => 'flo-label_for_mobile_menu',
                        'type' => 'text',
                        'title' => __('Enter label for mobile menu', 'flotheme'),
                        'default' => 'Menu',
                    ),
                    array(
                        'id' => 'flo-search_on_header',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __("Show search in the header ?", 'flotheme'),
                        'default' => '0'
                    ),
                    array(
                        'id' => 'flo-social_on_header',
                        'type' => 'button_set',
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'title' => __("Show social links in the header?", 'flotheme'),
                        'subtitle' => sprintf(__('All the social profile settings can be set  %s here %s ', 'flotheme'), '<a href="admin.php?page=_flo_options&tab=10" target="blank">', '</a>'),
                        'default' => '0'
                    ),

                    array(
                        'id' => 'flo-logo_text',
                        'type' => 'typography',
                        'title' => __('Text logo', 'flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'output' => array('header .logo a'),
                        'subtitle' => __('Set typography for text logo.', 'flotheme'),
                        'help_img' => 'text_logo.jpg',
                        'placeholder' => array(

                            'font-weight'  => '400',
                            'color' => '#504c49',
                            'google' => true,
                            'font-family' => '',
                            'font-size' => '18px',
                            'font-size-mobile' => '16px',
                            'font-size-tablet' => '17px',
                        ),
                    ),
                    array(
                        'id' => 'flo-menu',
                        'type' => 'typography',
                        'title' => __('Menu Typography', 'flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => false,
                        'units' => 'px',
                        'output' => array('.header_main-nav_link > li a '),
                        'help_img' => 'menu_settings.jpg',
                        'placeholder' => array(

                                'font-weight'  => '400',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '12px',
                            'font-size-mobile' => '12px',
                            'font-size-tablet' => '12px',
                            'letter-spacing' => '1.2px'
                        ),
                    ),
                    array(
                       'id' => 'menu-hover_color',
                       'type' => 'color',
                       'output' => array('.header_main-nav_link>li>a:hover'),
                       'title' => __('Menu hover color', 'flotheme'),
                       //'subtitle' => __('Pick a content text color for the theme .', 'flotheme'),
                       'default' => '',
                       'mode' => 'color',
                       'validate' => 'color',
                    ),
                    array(
                        'id' => 'flo-submenu_links',
                        'type' => 'typography',
                        'title' => __('Submenu Typography', 'flotheme'),
                        'google' => true,
                        'font-backup' => false,
                        'text-align' => false,
                        'font-style' => true, // Includes font-style and weight. Can use font-style or font-style to declare
                        'subsets' => true, // Only appears if google is true and subsets not set to false
                        'font-size' => true,
                        'font-size-mobile' => true,
                        'font-size-tablet' => true,
                        'line-height' => true,
                        'line-height-mobile' => true,
                        'line-height-tablet' => true,
                        'color' => true,
                        'letter-spacing' => true, // Defaults to false
                        'letter-spacing-mobile' => true, // Defaults to false
                        'letter-spacing-tablet' => true, // Defaults to false
                        'preview' => true, // Disable the previewer
                        'all_styles' => true,
                        'units' => 'px',
                        'help_img' => 'submenu_links.jpg',
                        'output' => array('.header_main-nav_link li .header_main-nav_sub-menu a'),
                        'placeholder' => array(

                                'font-weight'  => '400',
                            //'color'       => '#333',
                            //'font-style'  => '700',
                            'font-family' => '',
                            'google' => true,
                            'font-size' => '12px',
                            'font-size-mobile' => '12px',
                            'font-size-tablet' => '12px',
                        ),
                    ),
                    array(
                       'id' => 'submenu-hover_color',
                       'type' => 'color',
                       'output' => array('.header_main-nav_link .menu-item-has-children a:hover'),
                       'title' => __('Submenu hover color', 'flotheme'),
                       //'subtitle' => __('Pick a content text color for the theme .', 'flotheme'),
                       'default' => '',
                       'mode' => 'color',
                       'validate' => 'color',
                    ),
                )
            );
            $view_type = array(
                'thumb_view_title_over' => ReduxFramework::$_url . 'assets/img/icons/grid1.png',
                'grid_view' => ReduxFramework::$_url . 'assets/img/icons/grid2.png',
                'grid_50_50' => ReduxFramework::$_url . 'assets/img/icons/grid3.png',
                'grid_mosaic' =>ReduxFramework::$_url . 'assets/img/icons/grid4.png',
                'list_view_50_50'=> ReduxFramework::$_url . 'assets/img/icons/grid5.png',
                //'thumb_view_title_below' => ReduxFramework::$_url . 'assets/img/icons/grid6.png',
                'grid_view_featured_post'  => ReduxFramework::$_url . 'assets/img/icons/grid7.png',
                //'grid_pattern' => ReduxFramework::$_url . 'assets/img/icons/grid8.png',
            );
            $view_type_archives = array(
                'thumb_view_title_over' => ReduxFramework::$_url . 'assets/img/icons/grid1.png',
                'grid_view' => ReduxFramework::$_url . 'assets/img/icons/grid2.png',
                'grid_50_50' => ReduxFramework::$_url . 'assets/img/icons/grid3.png',
                'grid_mosaic' =>ReduxFramework::$_url . 'assets/img/icons/grid4.png',
                'list_view_50_50'=> ReduxFramework::$_url . 'assets/img/icons/grid5.png',
                //'thumb_view_title_below' => ReduxFramework::$_url . 'assets/img/icons/grid6.png',
                //'grid_pattern' => ReduxFramework::$_url . 'assets/img/icons/grid8.png',
            );
            $this->sections[] = array(
                'icon' => 'content-settings',
                'class' => 'content-settings',
                'title' => __('Content Settings', 'flotheme'),
                'fields' => array(

                    array(
                        'id' => 'flo-blog_listing_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => __('Blog listing layout ( view type )', 'flotheme'),
                        'subtitle' => __('Choose your blog layout.', 'flotheme'),
                        'options' => $view_type_archives,
                        'default' => 'thumb_view_title_over'
                    ),
                    array(
                        'id' => 'flo-page_listing_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => __('Page Listing layout ( view type )', 'flotheme'),
                        'subtitle' => __('Choose your page layout.', 'flotheme'),
                        'options' => $page_view_type,
                        'default' => '1'
                    ),
                    array(
                        'id' => 'flo-excerpt',
                        'type' => 'text',
                        'title' => __('Enter excerpt grid view length', 'flotheme'),
                        'subtitle' => __('It is used in grid views.', 'flotheme'),
                        'default' => '120',
                        'validate' => 'numeric'
                    ),
                    array(
                        'id' => 'flo-archive_listing_layout',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => __('Archive listing layout ( view type )', 'flotheme'),
                        'subtitle' => __('Choose your archive layout.', 'flotheme'),
                        'options' => $view_type_archives,
                        'default' => 'thumb_view_title_over'
                    ),
                    array(
                        'id' => 'flo-pagination_type',
                        'type' => 'image_select',
                        'compiler' => true,
                        'title' => __('Pagination Type', 'flotheme'),
                        'subtitle' => __('Choose your pagination type.', 'flotheme'),
                        'options' => $pag_type,
                        'default' => 'small'
                    ),

                    array(
                        'id' => 'change_gallery_shortcode',
                        'type' => 'button_set',
                        'title' => __('Change the default WP gallery shortcode behaviour', 'flotheme'),
                        'desc' => __('By enabling this option the layout and behaviour for the default WP gallery shortcode will be overwritten. Click on the image hint to see how it will look like.', 'flotheme'),
                        'options' => array(
                            'yes' => 'Yes',
                            'no' => 'No',
                        ),
                        'default' => 'yes'
                    ),
                )
            );

            $this->sections[] = array(
                'icon' => 'footer-settings',
                'class' => 'footer-settings',
                'title' => __('Footer Settings', 'flotheme'),
                'fields' => array(

	                array(
		                'id' => 'flo-enable_back_to_top_button',
		                'type' => 'button_set',
		                'options' => array(
				                '0' => 'Off',
				                '1' => 'On'
		                ),
		                'title' => __('Enable back to top button ?', 'flotheme'),
		                'default' => 1,
	                ),
                    array(
                       'id' => 'footer-background_color',
                       'type' => 'color',
                       'output' => array('.main-footer'),
                       'title' => __('Footer Background Color', 'flotheme'),
                       //'subtitle' => __('Pick a content text color for the theme .', 'flotheme'),
                       'default' => '',
                       'mode' => 'background-color',
                       'validate' => 'color',
                    ),
                    array(
                       'id' => 'footer-text_color',
                       'type' => 'color',
                       'output' => array('.main-footer, .main-footer a'),
                       'title' => __('Footer Text Color', 'flotheme'),
                       //'subtitle' => __('Pick a content text color for the theme .', 'flotheme'),
                       'default' => '',
                       'mode' => 'color',
                       'validate' => 'color',
                    ),
                    array(
                        'id' => 'opt-editor',
                        'type' => 'editor',
                        'title' => __('Copyright text', 'flotheme'),
                        'subtitle' => __('Type here the Copyright text that will appear in the footer.To display the current year use "%year%"', 'flotheme'),
                        'default' => '',
                    ),
                )
            );

            $this->sections[] = array(
                'icon' => 'social',
                'class' => 'social',
                //                'customizer' => false,
                'title' => __('Social Networks', 'flotheme'),
                'fields' => array(
                    array(
                        'id' => 'social',
                        'type' => 'social_networks',
                        'title' => __('Add social', 'flotheme'),
                        'description' => __("NOTE! The following services have font icons support: <b><i>facebook, twitter, gplus, yahoo, dribbble, linkedin, vimeo, youtube, tumblr, delicious, flickr, instagram, pinterest.</i></b> So if you are using any of this services then you are not required to upload icons for the social profile (if you leave the icon field blank the defaul icons will be used). But for any other social profiles you'll have to upload image icons.", 'flotheme'),
                    ),
                    array(
                        'id' => 'social_type',
                        'type' => 'button_set',
                        'title' => __("Show Only text ? ", 'flotheme'),
                        'description' => __("This options is used when social icons are used in the header. If this option is enabled, then instead of the icons for each social network we will show just it's name.", 'flotheme'),
                        'options' => array(
                            '0' => 'Off',
                            '1' => 'On'
                        ),
                        'default' => '0'
                    ),
                    array(
                        'id' => 'flo-social_links_label',
                        'type' => 'text',
                        'title' => __('Label For Social Links In Header', 'flotheme'),
                        'default' => __('Follow us on:', 'flotheme'),
                        'help_img' => 'social_links_label_header.jpg',
                    ),
                )
            );
            $this->sections[] = array(
                'icon' => 'labels',
                'class' => 'labels',
                'title' => __('Titles', 'flotheme'),
                'fields' => array(
                    array(
                        'id' => 'flo-blog_page_title',
                        'type' => 'text',
                        'title' => __('Blog page title', 'flotheme'),
                        'default' => __('Blog', 'flotheme')
                    ),
                    array(
                        'id' => 'flo-cat_page_title',
                        'type' => 'text',
                        'title' => __('Category page title', 'flotheme'),
                        'default' => __('Category archives: %', 'flotheme')
                    ),
                    array(
                        'id' => 'flo-tags_page_title',
                        'type' => 'text',
                        'title' => __('Tags page title', 'flotheme'),
                        'default' => __('Tags archives: %', 'flotheme')
                    ),
                    array(
                        'id' => 'flo-author_page_title',
                        'type' => 'text',
                        'title' => __('Author page title', 'flotheme'),
                        'default' => __('Author archives: %', 'flotheme')
                    ),
                    array(
                        'id' => 'flo-search_page_title',
                        'type' => 'text',
                        'title' => __('Search page title', 'flotheme'),
                        'default' => __('Search results: %', 'flotheme')
                    ),
                    array(
                        'id' => 'flo-other_archive_page_title',
                        'type' => 'text',
                        'title' => __('Archives page title', 'flotheme'),
                        'default' => __('Blog archives', 'flotheme')
                    ),
                    array(
                        'id' => 'flo-no_posts_found_msg',
                        'type' => 'text',
                        'title' => __('No posts found message', 'flotheme'),
                        'default' => __('Sorry, no posts were found.', 'flotheme')
                    ),
                    array(
                        'id' => 'flo-grid_reed_more_label',
                        'type' => 'text',
                        'title' => __('Label for read more in the<br/> grids', 'flotheme'),
                        'default' => __('read more', 'flotheme'),
                        'help_img' => 'grid_read_more_label.jpg',
                    ),
                )
            );

            $this->sections[] = array(
                'icon' => 'sidebar',
                'class' => 'sidebar',
                //                'customizer' => false,
                'title' => __('Sidebars', 'flotheme'),
                'fields' => array(
                    array(
                        'id' => 'sidebars',
                        'type' => 'sidebars',
                        'title' => __('Add sidebars', 'flotheme'),
                        'fields' => array(
                            array(
                                'id' => 'new_sidebar',
                                'type' => 'text',
                                'placeholder' => __('Add new Sidebar', 'flotheme'),
                            )
                        ),
                    )
                )
            );

            $this->sections[] = array(
                'icon' => 'custom-css',
                'class' => 'custom-css',
                'title' => __('Custom CSS', 'flotheme'),
                'fields' => array(
                    array(
                        'id' => 'flo-custom_css',
                        'type' => 'ace_editor',
                        'title' => __('CSS Code', 'flotheme'),
                        'subtitle' => __('Paste your CSS code here.', 'flotheme'),
                        'mode' => 'css',
                        'theme' => 'monokai',
                        //                        'desc' => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',
                        'default' => ""
                    ),
                )
            );
            //                $this->sections[] = array(
            //                    'type' => 'divide',
            //                );

            $theme_info = '<div class="redux-framework-section-desc">';
            $theme_info .= '<p class="redux-framework-theme-data description theme-uri">' . __('<strong>Theme URL:</strong> ', 'flotheme') . '<a href="' . $this->theme->get('ThemeURI') . '" target="_blank">' . $this->theme->get('ThemeURI') . '</a></p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-author">' . __('<strong>Author:</strong> ', 'flotheme') . $this->theme->get('Author') . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-version">' . __('<strong>Version:</strong> ', 'flotheme') . $this->theme->get('Version') . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-description">' . $this->theme->get('Description') . '</p>';
            $tabs = $this->theme->get('Tags');
            if (!empty($tabs)) {
                $theme_info .= '<p class="redux-framework-theme-data description theme-tags">' . __('<strong>Tags:</strong> ', 'flotheme') . implode(', ', $tabs) . '</p>';
            }
            $theme_info .= '</div>';

            $this->sections[] = array(
                'title' => __('Import / Export', 'flotheme'),
                'desc' => __('Import and Export your Redux Framework settings from file, text or URL.', 'flotheme'),
                'icon' => 'el-icon-refresh',
                'icon_class' => 'io',
                'fields' => array(
                    array(
                        'id' => 'opt-import-export',
                        'type' => 'import_export',
                        'title' => 'Import Export',
                        'subtitle' => 'Save and restore your Redux options',
                        'full_width' => false,
                    ),
                ),
            );

            $this->sections[] = array(
                'type' => 'divide',
            );

            // $this->sections[] = array(
            //     'icon' => 'el-icon-info-sign',
            //     'title' => __('Theme Information', 'flotheme'),
            //     //'desc' => __('<p class="description">This is the Description. Again HTML is allowed</p>', 'flotheme'),
            //     'icon_class' => 'about',
            //     'fields' => array(
            //         array(
            //             'id' => 'opt-raw-info',
            //             'type' => 'raw',
            //             'content' => $item_info,
            //         )
            //     ),
            // );

            if (file_exists(trailingslashit(dirname(__FILE__)) . 'README.html')) {
                $tabs['docs'] = array(
                    'icon' => 'el-icon-book',
                    'title' => __('Documentation', 'flotheme'),
                    'content' => nl2br(file_get_contents(trailingslashit(dirname(__FILE__)) . 'README.html'))
                );
            }
        }

        public function setHelpTabs()
        {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id' => 'redux-help-tab-1',
                'title' => __('Theme Information 1', 'flotheme'),
                'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'flotheme')
            );

            $this->args['help_tabs'][] = array(
                'id' => 'redux-help-tab-2',
                'title' => __('Theme Information 2', 'flotheme'),
                'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'flotheme')
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'flotheme');
        }

        /**
         * All the possible arguments for Redux.
         * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
         * */
        public function setArguments()
        {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name' => 'flo_options',
                // This is where your data is stored in the database and also becomes your global variable name.
                'display_name' => $theme->get('Name'),
                // Name that appears at the top of your panel
                'display_version' => $theme->get('Version'),
                // Version that appears at the top of your panel
                'menu_type' => 'menu',
                //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu' => true,
                // Show the sections below the admin menu item or not
                'menu_title' => __('Flothemes', 'flotheme'),
                'page_title' => __('Flothemes Options', 'flotheme'),
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => 'AIzaSyCqOjyQoMvmZf1mQecGc0qdwaRQ0V_mOsw',
                // Set it you want google fonts to update weekly. A google_api_key value is required.
                'google_update_weekly' => false,
                // Must be defined to add google fonts to the typography module
                'async_typography' => false,
                // Use a asynchronous font on the front end or font string
                //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
                'admin_bar' => true,
                // Show the panel pages on the admin bar
                'admin_bar_icon' => 'dashicons-portfolio',
                // Choose an icon for the admin bar menu
                'admin_bar_priority' => 50,
                // Choose an priority for the admin bar menu
                'global_variable' => '',
                // Set a different name for your global variable other than the opt_name
                'dev_mode' => false ,
                // Show the time the page took to load, etc
                'update_notice' => true,
                // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
                'customizer' => true,
                // Enable basic customizer support
                //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
                //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

                // OPTIONAL -> Give you extra features
                'page_priority' => NULL,
                // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent' => 'themes.php',
                // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions' => 'manage_options',
                // Permissions needed to access the options panel.
                'menu_icon' => get_template_directory_uri() . '/images/flothemes.ico',
                // Specify a custom URL to an icon
                'last_tab' => '',
                // Force your panel to always open to a specific tab (by id)
                'page_icon' => 'icon-themes',
                // Icon displayed in the admin panel next to your menu_title
                'page_slug' => '_flo_options',
                // Page slug used to denote the panel
                'save_defaults' => true,
                // On load save the defaults to DB before user clicks save or not
                'default_show' => false,
                // If true, shows the default value next to each field that is not the default value.
                'default_mark' => '',
                // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,
                // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time' => 60 * MINUTE_IN_SECONDS,
                'output' => true,
                // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag' => true,
                'hide_reset' => false,
                // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database' => '',
                // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info' => false,
                // REMOVE

                // HINTS
                'hints' => array(
                    'icon' => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color' => 'lightgray',
                    'icon_size' => 'normal',
                    'tip_style' => array(
                        'color' => 'light',
                        'shadow' => true,
                        'rounded' => false,
                        'style' => '',
                    ),
                    'tip_position' => array(
                        'my' => 'bottom left',
                        'at' => 'top center',
                    ),
                    'tip_effect' => array(
                        'show' => array(
                            'effect' => 'slide',
                            'duration' => '500',
                            'event' => 'mouseover',
                        ),
                        'hide' => array(
                            'effect' => 'slide',
                            'duration' => '500',
                            'event' => 'click mouseleave',
                        ),
                    ),
                )
            );

            if( !(defined('FLO_ENVIROMENT') && FLO_ENVIROMENT == 'DEV') ){
                $this->args['dev_mode'] = false;
            }
            
            // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
            $this->args['admin_bar_links'][] = array(
                'id' => 'redux-docs',
                'href' => 'http://docs.flothemes.com/',
                'title' => __('Documentation', 'flotheme'),
            );

            // $this->args['admin_bar_links'][] = array(
            //     //'id'    => 'redux-support',
            //     'href' => 'https://github.com/ReduxFramework/redux-framework/issues',
            //     'title' => __('Support', 'flotheme'),
            // );

            // $this->args['admin_bar_links'][] = array(
            //     'id' => 'redux-extensions',
            //     'href' => 'reduxframework.com/extensions',
            //     'title' => __('Extensions', 'flotheme'),
            // );

            //             SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
            // $this->args['share_icons'][] = array(
            //     'url' => 'https://github.com/ReduxFramework/ReduxFramework',
            //     'title' => 'Visit us on GitHub',
            //     'icon' => 'el-icon-github'
            //     //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
            // );
            $this->args['share_icons'][] = array(
                'url' => 'https://www.facebook.com/Flothemes',
                'title' => 'Like us on Facebook',
                'icon' => 'el-icon-facebook'
            );
            $this->args['share_icons'][] = array(
                'url' => 'https://twitter.com/flothemes',
                'title' => 'Follow us on Twitter',
                'icon' => 'el-icon-twitter'
            );
            // $this->args['share_icons'][] = array(
            //     'url' => 'http://www.linkedin.com/company/redux-framework',
            //     'title' => 'Find us on LinkedIn',
            //     'icon' => 'el-icon-linkedin'
            // );

            // Panel Intro text -> before the form
            // if (!isset($this->args['global_variable']) || $this->args['global_variable'] !== false) {
            //     if (!empty($this->args['global_variable'])) {
            //         $v = $this->args['global_variable'];
            //     } else {
            //         $v = str_replace('-', '_', $this->args['opt_name']);
            //     }
            //     $this->args['intro_text'] = sprintf(__('<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'flotheme'), $v);
            // } else {
            //     $this->args['intro_text'] = __('<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'flotheme');
            // }

            // Add content after the form.
            
            //$this->args['footer_text'] = __('<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'flotheme');
        }

        public function validate_callback_function($field, $value, $existing_value)
        {
            $error = true;
            $value = 'just testing';

            /*
			  do your validation

			  if(something) {
				$value = $value;
			  } elseif(something else) {
				$error = true;
				$value = $existing_value;

			  }
			 */

            $return['value'] = $value;
            $field['msg'] = 'your custom error message';
            if ($error == true) {
                $return['error'] = $field;
            }

            return $return;
        }

        public function class_field_callback($field, $value)
        {
            print_r($field);
            echo '<br/>CLASS CALLBACK';
            print_r($value);
        }

    }

    global $reduxConfig;
    $reduxConfig = new Redux_Framework_sample_config();
} else {
    echo "The class named Redux_Framework_sample_config has already been called. <strong>Developers, you need to prefix this class with your company name or you'll run into problems!</strong>";
}

/**
 * Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')):
    function redux_my_custom_field($field, $value)
    {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
 * Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')):
    function redux_validate_callback_function($field, $value, $existing_value)
    {
        $error = true;
        $value = 'just testing';

        /*
		  do your validation

		  if(something) {
			$value = $value;
		  } elseif(something else) {
			$error = true;
			$value = $existing_value;

		  }
		 */

        $return['value'] = $value;
        $field['msg'] = 'your custom error message';
        if ($error == true) {
            $return['error'] = $field;
        }

        return $return;
    }
endif;
