<?php

ini_set('max_execution_time', 60);
ini_set('memory_limit', '256M');
/**
 * options_sample functions and definitions
 *
 * @package options_sample
 */

define('_TN_', wp_get_theme());
function flo__autoload($class_name)
{
    if (substr($class_name, 0, 6) == 'widget') {
        $class_name = str_replace('widget_', '', $class_name);
        if (is_file(get_template_directory() . '/flo-options/ReduxCore/widget/' . $class_name . '.php')) {
            include get_template_directory() . '/flo-options/ReduxCore/widget/' . $class_name . '.php';

        }
    }
    if (is_file(get_template_directory() . '/flo-options/ReduxCore/' . $class_name . '.class.php')) {
        include_once get_template_directory() . '/flo-options/ReduxCore/' . $class_name . '.class.php';
    }

}

spl_autoload_register("flo__autoload");


if (!function_exists('flo_setup')) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function flo_setup()
    {

        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on options_sample, use a find and replace
         * to change 'flotheme' to the name of your theme in all the template files
         */
        load_theme_textdomain('flotheme', get_template_directory() . '/languages');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
         */
        add_theme_support('post-thumbnails');

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'primary' => __('Primary Menu', 'flotheme'),
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
        ));

        /*
         * Enable support for Post Formats.
         * See http://codex.wordpress.org/Post_Formats
         */
        add_theme_support('post-formats', array(
            'aside', 'image', 'video', 'quote', 'link',
        ));

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('flo_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));
    }
endif; // flo_setup
add_action('after_setup_theme', 'flo_setup');

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function flo_widgets_init() {
    register_sidebar(array(
        'name' => __('Sidebar', 'flotheme'),
        'id' => 'sidebar-1',
        'description' => '',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h1 class="widget-title">',
        'after_title' => '</h1>',
    ));
}

//add_action('widgets_init', 'flo_widgets_init');
include_once('floshortcodes/custom-functions.php');
/**
 * Enqueue scripts and styles.
 */
function flo_scripts() {
   
    if ( defined('FLO_ENVIROMENT') && FLO_ENVIROMENT == 'DEV') {
        wp_register_script('vendor', get_template_directory_uri() . '/js/vendor.js', array('jquery'), '', true);
        wp_register_script('scripts', get_template_directory_uri() . '/js/scripts.js', array('jquery'), '', true);
    } else {
        wp_register_script('vendor', get_template_directory_uri() . '/js/vendor.min.js', array('jquery'), '', true);
        wp_register_script('scripts', get_template_directory_uri() . '/js/scripts.min.js', array('jquery'), '', true);
    }

    wp_enqueue_script('vendor');
    wp_enqueue_script('scripts');

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}

add_action('wp_enqueue_scripts', 'flo_scripts');

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


// Redux framework
if (!class_exists('ReduxFramework') && file_exists(dirname(__FILE__) . '/flo-options/ReduxCore/framework.php')) {
    require_once(dirname(__FILE__) . '/flo-options/ReduxCore/framework.php');
}
if (!isset($redux_demo) && file_exists(dirname(__FILE__) . '/flo-options/config/config.php')) {
    require_once(dirname(__FILE__) . '/flo-options/config/config.php');
}

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if (!isset($content_width)) {
    if(isset($flo_options['flo-content_width'])){
        $content_width = $flo_options['flo-content_width']; /* pixels */
    }else{
        $content_width = 640;
    }
    
}


/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB directory)
 *
 * @category YourThemeOrPlugin
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/webdevstudios/Custom-Metaboxes-and-Fields-for-WordPress
 */


global $flo_options;
if (!empty($flo_options['sidebars'])) {
    $sidebars = $flo_options['sidebars'];
    /* register dinamic sidebar */
    if (function_exists('register_sidebar')) {
        if (is_array($sidebars) && !empty($sidebars)) {
            foreach ($sidebars as $sidebar) {
                if (isset($sidebar['title']) && !empty($sidebar['title'])) {
                    register_sidebar(array(
                        'name' => $sidebar['title'],
                        'id' => trim(strtolower(str_replace(' ', '-', $sidebar['title']))),
                        'before_widget' => '<aside id="%1$s" class="widget"><div class="%2$s">',
                        'after_widget' => '</div></aside>',
                        'before_title' => '<h5 class="widget-title">',
                        'after_title' => '</h5><p class="widget-delimiter">&nbsp;</p>',
                    ));
                }
            }
        }
    }
    $admin_bar_show = $flo_options['flo-show_admin_bar'];
    if (!$admin_bar_show) {
        add_filter('show_admin_bar', '__return_false');
    }
}


define('FLOTHEME_CUSTOMIZED', false); // set to TRUE if you changed something in the source code.
define('FLOTHEME_THEME_VERSION', theme_data_variable('Version'));

require_once('flo-options/ReduxCore/update.php');
require_once('flo-options/ReduxCore/resources.register.php');

/**********************************************/
/************ Plugin recommendations **********/
/**********************************************/
require_once('flo-options/ReduxCore/plugin-recommendations.php');


function flo_load_scripts()
{
global $flo_options;
    /*NEW STYLES*/
    wp_register_style('vendor', get_template_directory_uri() . '/css/vendor.min.css');
    wp_enqueue_style('vendor');
    /* bxSlider CSS file */

    if ( defined('FLO_ENVIROMENT') && FLO_ENVIROMENT == 'DEV') {
        wp_register_style('theme_stylesheet', get_template_directory_uri() . '/css/style.css');
    } else {
        wp_register_style('theme_stylesheet', get_template_directory_uri() . '/css/style.min.css');
    }

    wp_enqueue_style('theme_stylesheet');

	wp_register_style( 'default_stylesheet',get_stylesheet_directory_uri() . '/style.css' );
	wp_enqueue_style( 'default_stylesheet' );


    

    // predefined stylesheets
    if( isset($flo_options['flo-style_sheet']) && $flo_options['flo-style_sheet'] != '' ){
        wp_register_style( 'predefined_stylesheet',get_stylesheet_directory_uri() . '/css/'.$flo_options['flo-style_sheet'] );
        wp_enqueue_style( 'predefined_stylesheet' );
    }


    /*END NEW STYLES*/

    // we need this for comment-reply
    if (is_singular()) {
        wp_enqueue_script("comment-reply");
    }

    $siteurl = get_option('siteurl');
    if (!empty($siteurl)) {
        $siteurl = rtrim($siteurl, '/') . '/wp-admin/admin-ajax.php';
    } else {
        $siteurl = home_url('/wp-admin/admin-ajax.php');
    }



    $flo_config['heroSlider'] = true;
    if(isset($flo_options) && isset($flo_options['flo-header_type']) && $flo_options['flo-header_type'] != ''){
        $header_type = $flo_options['flo-header_type'];
        if($header_type == 'header_hamburger'){
            $flo_config['headerSlideDown'] = true;
        }
    }
	if(isset($flo_options) && isset($flo_options['flo-main_slideshow_autoplay']) && $flo_options['flo-main_slideshow_autoplay'] != ''){
		if($flo_options['flo-main_slideshow_autoplay'] == '1'){
			$flo_config['autoplay'] = true;
		}else{
			$flo_config['autoplay'] = false;
		}
	}
	if(isset($flo_options) && isset($flo_options['flo-autoplay_speed']) && $flo_options['flo-autoplay_speed'] != ''){
		$flo_config['autoplay_speed'] = $flo_options['flo-autoplay_speed'];
	}
	if(isset($flo_options) && isset($flo_options['flo-enable_sticky_header']) && $flo_options['flo-enable_sticky_header'] == '1'){
		$flo_config['enableStickyHeader'] = $flo_options['flo-enable_sticky_header'];
	}

    $flo_js_data = array(
        'site_width' => $flo_options['flo-content_width'],
        // check if we have  saved the value we need to adjust the Header type 4 distance between
        //menu items situated on the left side of the menu
        'header_logo_center_menu_left_spacing' => get_option('header_logo_center_menu_left_spacing', '0px'),

        // check if we have  saved the value we need to adjust the Header type 4 distance between
        //menu items situated on the right side of the menu
        'header_logo_center_menu_right_spacing' => get_option('header_logo_center_menu_right_spacing', '0px'),

        // generate a nonce with a unique ID "header_4_menu_spacing_nonce_val"
        // so that you can check it later when an AJAX request is sent
        'header_logo_center_menu_spacing_nonce' => wp_create_nonce( 'header_logo_center_menu_spacing_nonce_val' ),
    );
    add_action('wp_enqueue_scripts', 'flo_load_scripts');
    if (!is_admin()) {
        add_action('wp_head', 'cosmo_get_custom_css');

        //if('header_style2' == options::get_value('header_settings' , 'header_logo_style')){ // we may have a transparent header if there is a slideshow

    }


    wp_localize_script( 'scripts', 'flo_js_data', $flo_js_data );


    wp_localize_script( 'scripts', 'floConfig', $flo_config); // localize visible nearby slideshow img width
    wp_localize_script( 'scripts', 'ajaxurl', $siteurl );


}

add_action('wp_enqueue_scripts', 'flo_load_scripts');


//function return class for columns
 function get_col_class($nr_of_columns){
     if($nr_of_columns == '1'){
         $block_class = 'medium-12';
     }elseif($nr_of_columns == '2'){
         $block_class = 'medium-6';
     }elseif($nr_of_columns == '3'){
         $block_class = 'medium-4';
     }elseif($nr_of_columns == '4'){
         $block_class = 'medium-3';
     }elseif($nr_of_columns == '6'){
         $block_class = 'medium-2';
     }else{
         $block_class = 'medium-4';
     }
     return $block_class;
 }

function flo_get_col_featured_big($nr_of_col){
    if($nr_of_col == '3'){
        $block_class_big = 'medium-8';
    }elseif($nr_of_col == '4'){
        $block_class_big = 'medium-6';
    }elseif($nr_of_col == '6'){
        $block_class_big = 'medium-6';
    }else{
        $block_class_big = 'medium-6';
    }
    return $block_class_big;
}

function flo_get_col_featured_small($nr_of_col){
    if($nr_of_col == '3'){
        $block_class_small = 'medium-4';
    }elseif($nr_of_col == '4'){
        $block_class_small = 'medium-3';
    }elseif($nr_of_col == '6'){
        $block_class_small = 'medium-2';
    }else{
        $block_class_small = 'medium-4';
    }
    return $block_class_small;
}

function flo_view_type_classes($view_type){
    if (isset($view_type)) {
        switch($view_type){
            case 'thumb_view_title_over':
                $view_type_class = ' columns-full-width ';
                break;
            case 'thumb_view_title_over':
                $view_type_class = ' columns-full-width ';
                break;
            case 'grid_view':
                $view_type_class = ' columns-image-vertical ';
                break;
            case 'grid_50_50':
                $view_type_class = ' columns-image-horizontal ';
                break;
            case 'grid_mosaic':
                $view_type_class = ' mosaic-grid ';
                break;
            case 'list_view_50_50':
                $view_type_class = ' one-column-vertical ';
                break;
            case 'thumb_view_title_below':
                $view_type_class = ' columns-vertical-only-title ';
                break;
            case 'grid_view_featured_post':
                $view_type_class = ' six-square-grid ';
                break;
	        case 'grid_pattern':
		        $view_type_class = ' page post-archive ';
		        break;
            default:
                $view_type_class = ' columns-full-width ';
        }

    }
    return $view_type_class;
}

function flo_comment($comment, $args, $depth) {
    global $comment_data;

    $comment_data = array(
        "args" => $args,
        "depth" => $depth,
        "comment" => $comment
    );

    echo get_template_part('parts/comment', '');
}


function pagination($first=1,$last=1,$middle=5,$baseURL=false,$wp_query=false ) {
	//if(!$baseURL) $baseURL= get_bloginfo('url');
    $baseURL = esc_url( home_url() );
	if(!$wp_query)global $wp_query;
	$page = $wp_query->query_vars["paged"];
	if ( !$page ) $page = 1;
	$qs = $_SERVER["QUERY_STRING"] ? "?".$_SERVER["QUERY_STRING"] : "";
	if ( $wp_query->found_posts > $wp_query->query_vars["posts_per_page"] ) {// Only necessary if there's more posts than posts-per-page


		$dots=false;
		for ( $i=1; $i <= $wp_query->max_num_pages; $i++ ){ // Loop through pages
			if($i<=$first || $i<=$middle && $page<$middle || $i>$wp_query->max_num_pages-$last || $i>$wp_query->max_num_pages-$middle && $page>$wp_query->max_num_pages-$middle+1 || $i>$page-ceil($middle/2) && $i<=$page+floor($middle/2)){
				if ( $i == $page ) { // Current page or linked page?
					echo '<li class="active">'.$i.'</li>';
				} else {
					echo '<li><a href="'.$baseURL.(($i!=1)?('page/'.$i.'/'):'').$qs.'">'.$i.'</a></li>';
				}
				$dots=false;
			}elseif(!$dots){
				echo '<li class="delim">...</li>';
				$dots=true;
			}
		}

	}
}

function new_excerpt_more( $more ) {
	return ' ...';
}
add_filter('excerpt_more', 'new_excerpt_more');

/* editor-style CSS*/
add_editor_style(
    array(
        get_template_directory_uri() .'/editor-style.css'
    )
);


// add container around the videos to make them responsive
add_filter( 'embed_oembed_html', 'custom_oembed_filter', 10, 4 ) ;

function custom_oembed_filter($html, $url, $attr, $post_ID) {

    if(strstr($url,'youtube') || strstr($url,'vimeo')){
        $return = '<div class="video-container-embeded">'.$html.'</div>';
    }else{
        $return = $html;
    }
    
    return $return;
}

if ( ! function_exists( 'flo_lightroom_gallery' ) ) :
/**
 * This function is ment for the compatibility with FloLightroom plugin
 *
 * It returns the available gallery types and the meta name where the gallery type should be saved
 *
 */
    function flo_lightroom_gallery(){
        $img_path_start = get_template_directory_uri() . '/lib/images/pattern/';
        // $gallery_layouts = array(   'content_down' => $img_path_start.'content_down.png',
        //                             'fixed_content' => $img_path_start.'fixed_content.png',
        //                             'full_width' => $img_path_start.'full_width.png'
        //                         );
        $gallery_layouts = array(
                'two_columns' => ReduxFramework::$_url . 'assets/img/icons/gallery1.png',
                'horizontal_long' => ReduxFramework::$_url . 'assets/img/icons/gallery3.png',
                'fixed_with_thumbs' =>ReduxFramework::$_url . 'assets/img/icons/gallery2.png',
                'one_line' => ReduxFramework::$_url . 'assets/img/icons/single2.png',
            );

        $gallery_type_meta = "flo_options['flo-gallery_type']";
        //$gallery_type_meta = "_cmb2_gallery_view_type";

        return array('gallery_layouts' => $gallery_layouts,
                    'gallery_type_meta' => $gallery_type_meta
        );
    }
endif; // flo_lightroom_gallery

add_action("after_switch_theme", "flo_redirect_quik_setup");
function flo_redirect_quik_setup(){
    //var_dump(ReduxFramework::$wp_content_url);
    wp_redirect( admin_url().'/admin.php?page=_flo_options&tab=0', 301 );
}